==> igniteui-react-core-16.16.0.tgz: package/esm5/lib/WebTreeSelectionOptionsEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTreeSelectionOptionsEventArgsDescription, _super);
    function WebTreeSelectionOptionsEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebTreeSelectionOptionsEventArgsDescription.prototype.get_type = function () {
        return "WebTreeSelectionOptionsEventArgs";
    };
    Object.defineProperty(WebTreeSelectionOptionsEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeSelectionOptionsEventArgsDescription.prototype, "newSelection", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("NewSelection");
        },
        enumerable: false,
        configurable: true
    });
    WebTreeSelectionOptionsEventArgsDescription.$t = markType(WebTreeSelectionOptionsEventArgsDescription, 'WebTreeSelectionOptionsEventArgsDescription', Description.$);
    return WebTreeSelectionOptionsEventArgsDescription;
}(Description));
export { WebTreeSelectionOptionsEventArgsDescription };

==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebTreeSelectionOptionsEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebTreeSelectionOptionsEventArgsDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebTreeSelectionOptionsEventArgsDescription, _super);
    function WebTreeSelectionOptionsEventArgsDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        return _this;
    }
    WebTreeSelectionOptionsEventArgsDescription.prototype.get_type = function () {
        return "WebTreeSelectionOptionsEventArgs";
    };
    Object.defineProperty(WebTreeSelectionOptionsEventArgsDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebTreeSelectionOptionsEventArgsDescription.prototype, "detail", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("Detail");
        },
        enumerable: false,
        configurable: true
    });
    WebTreeSelectionOptionsEventArgsDescription.$t = markType(WebTreeSelectionOptionsEventArgsDescription, 'WebTreeSelectionOptionsEventArgsDescription', Description.$);
    return WebTreeSelectionOptionsEventArgsDescription;
}(Description));
export { WebTreeSelectionOptionsEventArgsDescription };
